juham_openweathermap
====================

`juham_openweathermap` plugs OpenWeatherMap weather forecast service to Juham - Juha's Ultimate
Home Automation Masterpiece application.



Features
--------

The main purpose is to acquire solar energy forecast, for optimizing energy management in
homes with solar panels. 


Installation
------------

The installation is two stage process

1. To install:

.. code-block:: python

    pip install juham_openweathermap


2. Configure

   OpenWeatherMap requires you to register and obtain web key, through which you can
   access their forecast services. So sign in to openweathermap.com to obtain the key,
   and then add the web key to the '~/.[app]/config/OpenWeatherMap.json' configuration
   file.



License
-------

This project is licensed under the MIT License - see the `LICENSE` file for details.
